import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_dynamic_ui/component/base_card.dart';
import 'package:flutter_dynamic_ui/flutter_dynamic_ui.dart';
import 'package:flutter_dynamic_ui/model/data_model.dart';

class HorizontalListCard extends BaseCard {
  static final type = "default_card_horizontal_list";

  @override
  Widget createWidget(BuildContext context, CardData cardData) {
    final children = <Widget>[];
    if (cardData.topBanner != null) {
      children.add(_buildBanner(context, cardData.topBanner));
    }
    children.add(Container(
      width: double.maxFinite,
      height: 160,
      child: ListView.separated(
        shrinkWrap: true,
        scrollDirection: Axis.horizontal,
        itemBuilder: (context, index) =>
            _buildItemView(context, cardData, index),
        itemCount: cardData.blockList.length,
        padding: EdgeInsets.all(10),
        separatorBuilder: (BuildContext context, int index) {
          return SizedBox(
            width: 12,
          );
        },
      ),
    ));
    if (cardData.bottomBanner != null) {
      children.add(_buildBanner(context, cardData.bottomBanner));
    }
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: children,
    );
  }

  Widget _buildItemView(BuildContext context, CardData cardData, int index) {
    BlockData blockData = cardData.blockList[index];
    return BlockManager.getInstance().getBlockWidget(context, blockData);
  }

  Widget _buildBanner(BuildContext context, BlockData data) {
    return BlockManager.getInstance().getBlockWidget(context, data);
  }
}
